CreateImageFromPDFResponse class

Constructors

CreateImageFromPDFResponse({String? status = Status.empty, List<String?>? response, String? message})

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
response ↔ List<String?>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited